"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processTableOfContents = exports.resetTocContext = void 0;
const crypto_1 = require("crypto");
// Hash 생성 시 사용할 캐시
const hashCache = new Map();
// 헤딩 레벨 트래킹을 위한 변수들
let lastH1Hash = "";
let lastH2Hash = "";
let lastH1Title = "";
let lastH2Title = "";
const resetTocContext = () => {
    lastH1Hash = "";
    lastH2Hash = "";
    lastH1Title = "";
    lastH2Title = "";
};
exports.resetTocContext = resetTocContext;
const processTableOfContents = async (block, tableOfContents) => {
    if (["heading_1", "heading_2", "heading_3"].includes(block.type) &&
        block[block.type]?.rich_text?.length > 0) {
        const plainText = block[block.type]?.rich_text?.[0]?.plain_text || "";
        // 부모 컨텍스트 추가
        let contextualId = plainText;
        let parentHash = "";
        let level = 0;
        // 상위 헤딩에 따라 컨텍스트 저장
        if (block.type === "heading_1") {
            lastH1Title = plainText;
            lastH2Title = "";
            contextualId = `h1-${plainText}`;
            level = 1;
            // heading_1은 최상위 레벨이므로 부모가 없음
        }
        else if (block.type === "heading_2") {
            lastH2Title = plainText;
            contextualId = `h2-${lastH1Title}-${plainText}`;
            parentHash = lastH1Hash; // heading_2의 부모는 가장 최근의 heading_1
            level = 2;
        }
        else if (block.type === "heading_3") {
            contextualId = `h3-${lastH1Title}-${lastH2Title}-${plainText}`;
            parentHash = lastH2Hash || lastH1Hash; // heading_3의 부모는 가장 최근의 heading_2, 없으면 heading_1
            level = 3;
        }
        // 이미 처리된 플레인텍스트인지 확인
        let hash;
        if (hashCache.has(contextualId)) {
            hash = hashCache.get(contextualId);
        }
        else {
            hash = `link-${plainText
                .replace(/[^a-zA-Z0-9가-힣\s-_]/g, "")
                .trim()
                .replace(/\s+/g, "-")
                .toLowerCase()}-${(0, crypto_1.randomUUID)().substring(0, 4)}`;
            hashCache.set(contextualId, hash);
        }
        // 현재 해시 저장
        if (block.type === "heading_1") {
            lastH1Hash = hash;
        }
        else if (block.type === "heading_2") {
            lastH2Hash = hash;
        }
        block.hash = hash;
        // 중복 체크 - 동일한 hash가 이미 존재하는지 확인
        const existingTocIndex = tableOfContents.findIndex((toc) => toc.hash === hash);
        if (existingTocIndex === -1) {
            tableOfContents.push({
                type: block.type,
                hash,
                title: plainText,
                parentHash,
                level,
            });
        }
    }
};
exports.processTableOfContents = processTableOfContents;
