import { Reporter } from "gatsby";
/**
 * TocEntry interface representing a table of contents entry
 */
export interface TocEntry {
    type: string;
    hash: string;
    title: string;
    parentHash?: string;
    level?: number;
    contextTitle?: string;
}
/**
 * Utility function to efficiently handle large table of contents arrays
 * by removing duplicates and optionally limiting size while preserving hierarchy
 */
export declare const optimizeTocArray: (tocEntries: TocEntry[], reporter: Reporter, options?: {
    maxSize?: number;
    warnThreshold?: number;
    removeDuplicates?: boolean;
    structureByLevel?: boolean;
    enhanceDuplicates?: boolean;
}) => TocEntry[];
/**
 * Enhances TOC entries with contextual titles to disambiguate duplicate titles
 */
export declare const enrichDuplicateTitles: (tocEntries: TocEntry[], reporter: Reporter) => void;
